Module efmt_core::parse

source ·

Structs

Enums

Traits

  • This trait allows parsing an item from a token stream.
  • This trait allows resuming to parse an item from a token stream.

Type Aliases

Derive Macros