pub trait ResumeParse<A>: Parse {
// Required method
fn resume_parse(ts: &mut TokenStream, args: A) -> Result<Self>;
}Expand description
This trait allows resuming to parse an item from a token stream.
Required Methods
Sourcefn resume_parse(ts: &mut TokenStream, args: A) -> Result<Self>
fn resume_parse(ts: &mut TokenStream, args: A) -> Result<Self>
Resume to parse an item from the given token stream.
The second argument is the item that has already been parsed from the stream.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".